function DescriptiveStats(X, sigma,name,symmetric,cluster_index)
% X has 1 column, initial estimate unscaled, sigma=sigma1

critval=1.96;
n=length(X);
circlesize=75/sqrt(n);
GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];


circlesize=circlesize*4;
    
significant=(abs(X./sigma)>critval);
nooutlier=sigma<50; %added to exclude psych outlier
    
fig=figure('Visible','on',...
    'PaperUnits', 'inches',...
    'PaperPosition',[0 0 3 3],...
    'PaperSize',[3 3]);
    
rangeX=1.1*max(max(abs(X)), max(abs(sigma(nooutlier)))*critval);
    
axis([-rangeX rangeX 0 rangeX/critval])
hold on;
line([0, rangeX],[0, rangeX/critval],'Color',GREY);
line([-rangeX,0],[rangeX/critval,0],'Color',GREY);
    
    
scatter(X(~significant&nooutlier), sigma(~significant&nooutlier), circlesize,GREY,'filled');
scatter(X(significant&nooutlier), sigma(significant&nooutlier), circlesize,BLUE,'filled');
    
xlabel('X','FontSize',9);
ylabel('\Sigma','FontSize',9);
axis square
    
print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'Scatter.pdf'])

close all

%%
%Histograms of Z statistics

fig=figure('Visible','on',...
    'PaperUnits', 'inches',...
    'PaperPosition',[0 0 6 2.5],...
    'PaperSize',[6 2.5])
circlesize=50/sqrt(n);
    
    
subplot(1,2,2)
circlesize=circlesize*4;
    
significant=(abs(X./sigma)>critval);
nooutlier=sigma<50; %added to exclude psych outlier
    
rangeX=1.1*max(max(abs(X)), max(abs(sigma(nooutlier)))*critval);
    
axis([-rangeX rangeX 0 rangeX/critval])
hold on;
line([0, rangeX],[0, rangeX/critval],'Color',GREY);
line([-rangeX,0],[rangeX/critval,0],'Color',GREY);
    
    
scatter(X(~significant&nooutlier), sigma(~significant&nooutlier), circlesize,GREY,'filled');
scatter(X(significant&nooutlier), sigma(significant&nooutlier), circlesize,BLUE,'filled');
    
xlabel('X','FontSize',9);
ylabel('\Sigma','FontSize',9);
axis square
    
print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'CombinedScatter.pdf'])
    
    
    
subplot(1,2,1)
    
Zuse=X./sigma;
if max(abs(Zuse))>10
    Zuse(abs(Zuse)>6)=[];
end
    
ll=floor(min(Zuse));
lleven=floor(ll/2)*2;
uu=ceil(max(Zuse));

if n>=30
    uu2=ceil((uu-.36)/.32)*.32+.36;
    ll2=floor((ll+.36)/.32)*.32-.36;
    edges=[ll2:.32:-.36 0 .36:.32:uu2];
else
    uu2=ceil((uu-.68)/.64)*.64+.68;
    ll2=floor((ll+.68)/.64)*.64-.68;
    edges=[ll2:.64:-.68 0 .68:.64:uu2];
end
    
    
hold off
h=histogram(Zuse,edges,'normalization','probability');
h.FaceColor = BLUE;
h.FaceAlpha = 1;
hold on
axis([min(edges) max(edges) 0 max(h.Values)*1.1]);

L1=line([-1.96, -1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
L2=line([0, 0],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-.');
line([1.96, 1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
%line([1.64, 1.64],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle',':');
xlabel('X/\Sigma','FontSize',9);
ylabel('Density','FontSize',9)
%l=legend([L1 L2],'|Z|=1.96','|Z|=1.64','Location','NW')

ax = gca;
ax.XTick=lleven:2:uu;
box off
h.EdgeColor = 'none';
axis square
print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'ScatterHist.pdf'])

end