%options for optimization and numerical derivatives
options=optimset('MaxFunEvals',10^5,'MaxIter',10^5,'TolFun',10^-8);
%options=optimset('MaxFunEvals',10^3,'MaxIter',10^3,'TolFun',10^-8);

%Estimate model with metastudy specifications
GMM_obj=@(Psi)...
    MetastudyGMMObjective([Psi 1], cutoffs, symmetric, X, sigma,cluster_ID)+max(-min(Psi),0)*10^5;

[Psihat1, Objval] = fminunc(GMM_obj,Psihat0,options);
[Psihat, Objval] = fminsearch(GMM_obj,Psihat1,options);

GMM_obj_new=@(Psi)...
    MetastudyGMMObjective_new([Psi Psihat 1], cutoffs, symmetric, X, sigma, cluster_ID)+max(-min(Psi),0)*10^5;

[Psihat1_theta, Objval_new] = fminunc(GMM_obj_new,Psihat0_theta,options);
[Psihat_theta, Objval_new] = fminsearch(GMM_obj_new,Psihat1_theta,options);

Psihat_all = [Psihat_theta Psihat];

[moments, Sigma_temp, rhat]=MetastudyMoments_new([Psihat_all 1], cutoffs, symmetric, X, sigma);
Sigma_hat=Clustered_covariance_estimate(rhat,cluster_ID);

stepsize=10^-3;
G=zeros(size(moments,2),length(Psihat_all));
for n1=1:length(Psihat_all)
    beta_plus=Psihat_all;
    beta_plus(n1)=beta_plus(n1)+stepsize;
    moments_plus=MetastudyMoments_new([beta_plus 1], cutoffs, symmetric, X, sigma);
    beta_minus=Psihat_all;
    beta_minus(n1)=beta_minus(n1)-stepsize;
    moments_minus=MetastudyMoments_new([beta_minus 1], cutoffs, symmetric, X, sigma);
    G(:,n1)=(moments_plus-moments_minus)'/(2*stepsize);
end
Varhat_all=(G'*Sigma_hat^-1*G)^-1/length(X);
se_robust=diag(Varhat_all).^.5;
dof=size(moments,2);
Varhat = Varhat_all(3:end,3:end);

if length(cutoffs)==1
    Psi_grid=[0.001:.001:5 10 10^5];
    S_store=zeros(length(Psi_grid),1);
    
    for m=1:length(Psi_grid)
        S_store(m,1)=GMM_obj(Psi_grid(m));
    end
    
    CS_LB=min(Psi_grid(S_store<chi2inv(.95,1)));
    CS_UB=max(Psi_grid(S_store<chi2inv(.95,1)));
elseif length(cutoffs)==2
    gridsteps=200;
    Psi_grid1=[0.01:(.25-0.01)/(gridsteps-1):.25];
    Psi_grid2=[0.05:(5-0.05)/(gridsteps-1):5];
    S_store=zeros(length(Psi_grid1),length(Psi_grid2));
    for m1=1:length(Psi_grid1)
        for m2=1:length(Psi_grid2)
            Psi_temp=[Psi_grid1(m1) Psi_grid2(m2)];
            S_store(m1,m2)=GMM_obj(Psi_temp);
        end
    end
    
    Psi_grid=[Psi_grid1' Psi_grid2'];
else
    Psi_grid=[0.001:.001:5 10 10^5];
    S_store=zeros(length(Psi_grid),1);
end

SelectionTableGMM_ALL(Psihat_all,se_robust,'GMMEstimatesAll',S_store,Psi_grid,dof)
dof = size(moments(3:end),2);
SelectionTableGMM(Psihat,se_robust(3:end),name,S_store,Psi_grid,dof,dorobust)



