GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];

%normalize estimates from initial study
Z1=sort(X./sigma);

alpha=0.05;
bonf_alpha=0.04;
bonf_beta=0.01;

%Pad Psihat_use with additional zeros in symmetric specifications to make
%dimensions conform

Psihat_use=Psihat;


%Calculate corrected estimates and confidence bounds
stepsize=10^-3;
for n=1:length(Z1)
    g_U=@(lambda)(alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
    g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
    g_M=@(lambda) (1/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
    
    Z1_M(n,1)=fminsearch(g_M,Z1(n));
    Z1_U(n,1)=fminsearch(g_U,Z1(n));
    Z1_L(n,1)=fminsearch(g_L,Z1(n));
end

%Calculate Bonferroni corrected estimates and confidence bounds
for n=1:length(Z1)
    g_UB=@(lambda)(bonf_alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
    g_LB=@(lambda)(1-bonf_alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
    
    Z1_UB(n,1)=fminsearch(g_UB,Z1_U(n,1));
    Z1_LB(n,1)=fminsearch(g_LB,Z1_L(n,1));
    
    %Calculate derivatives of corrections with respect to parameters via
    %implicit function theorem
    thetaU_plus=Z1_UB(n,1)+stepsize;
    thetaU_minus=Z1_UB(n,1)-stepsize;
    F_Uplus=Step_function_normal_cdf(Z1(n),thetaU_plus,1,[Psihat_use 1],cutoffs,symmetric);
    F_Uminus=Step_function_normal_cdf(Z1(n),thetaU_minus,1,[Psihat_use 1],cutoffs,symmetric);
    dFUdtheta=(F_Uplus-F_Uminus)/(2*stepsize);
    
    thetaL_plus=Z1_LB(n,1)+stepsize;
    thetaL_minus=Z1_LB(n,1)-stepsize;
    F_Lplus=Step_function_normal_cdf(Z1(n),thetaL_plus,1,[Psihat_use 1],cutoffs,symmetric);
    F_Lminus=Step_function_normal_cdf(Z1(n),thetaL_minus,1,[Psihat_use 1],cutoffs,symmetric);
    dFLdtheta=(F_Lplus-F_Lminus)/(2*stepsize);
    
    for n1=1:length(Psihat_use)
        Psi_plus=Psihat_use;
        Psi_plus(n1)=Psi_plus(n1)+stepsize;
        Psi_minus=Psihat_use;
        Psi_minus(n1)=Psi_minus(n1)-stepsize;
        
        F_Uplus=Step_function_normal_cdf(Z1(n),Z1_UB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
        F_Uminus=Step_function_normal_cdf(Z1(n),Z1_UB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
        dFUdbeta(n1,1)=(F_Uplus-F_Uminus)/(2*stepsize);
        
        F_Lplus=Step_function_normal_cdf(Z1(n),Z1_LB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
        F_Lminus=Step_function_normal_cdf(Z1(n),Z1_LB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
        dFLdbeta(n1,1)=(F_Lplus-F_Lminus)/(2*stepsize);
    end
    dthetaUdbeta=-dFUdbeta/dFUdtheta;
    dthetaLdbeta=-dFLdbeta/dFLdtheta;
    if symmetric==1
        sigma_thetaU=(dthetaUdbeta'*Varhat*dthetaUdbeta)^.5;
        sigma_thetaL=(dthetaLdbeta'*Varhat*dthetaLdbeta)^.5;
    else
        sigma_thetaU=(dthetaUdbeta'*Varhat*dthetaUdbeta)^.5;
        sigma_thetaL=(dthetaLdbeta'*Varhat*dthetaLdbeta)^.5;
    end
end

sigma_U(n,1)=sigma_thetaU;
sigma_L(n,1)=sigma_thetaL;
    
Z1_UB_store=Z1_UB;
Z1_LB_store=Z1_LB;
Z1_UB=Z1_UB+norminv(1-bonf_beta)*sigma_U;
Z1_LB=Z1_LB-norminv(1-bonf_beta)*sigma_L;




count=1;
for lambda=-10:.01:10
    store(count)=g_M(lambda);
    count=count+1;
end

%% Plot original and adjusted confidence sets
Rl=min(min(Z1_L), min(Z1)-2)-0.5;
Ru=max(max(Z1_U), max(Z1)+2)+0.5;
R=Ru-Rl;

H=3.5;
W=6;

fig=figure('Visible','on',...
    'PaperUnits', 'inches',...
    'PaperPosition',[0 0 W H],...
    'PaperSize',[W H])

ax=axes
hold on
axis([Rl/R*W Ru/R*W 0 H])
set(ax, 'XAxisLocation', 'top')
ax.YTick=1/n:H/n:H;
ax.YTickLabel = Studynames;
ax.XTick=(ceil(Rl/2):1:floor(Ru/2))/R*W*2;
ax.XTickLabel = ceil(Rl/2)*2:2:floor(Ru/2)*2+10^-8;
ax.FontSize=9;
line([0 0],[0 n+1],'Color',GREY)
line([1.96/R*W 1.96/R*W],[0 n+1],'Color',GREY)
line([-1.96/R*W -1.96/R*W],[0 n+1],'Color',GREY)


sc1=scatter(Z1/R*W, (1:n)/n*H, 4, BLUE, 'x') %original
sc2=scatter(Z1_M/R*W, ((1:n)-.3)/n*H, 4,[0 0 0], 'filled') %adjusted


for i=1:n
    line([Z1(i)-1.96 Z1(i)+1.96]/R*W,[i i]/n*H,'Color',BLUE,'Linewidth',1) %original
    line([Z1_L(i) Z1_U(i)]/R*W,([i i]-.3)/n*H,'Color',[0 0 0],'Linewidth',1) %adjusted
end


legend([sc1 sc2],{'Original Estimates','Adjusted Estimates'},'Location','SE', 'FontSize', 9)


print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'OriginalAndAdjusted.pdf'])

%% Plot original and adjusted confidence sets, including bonferroni
Rl=min(min(Z1_LB), min(Z1)-2)-0.5;
Ru=max(max(Z1_UB), max(Z1)+2)+0.5;
R=Ru-Rl;

H=3.5;
W=6;

fig=figure('Visible','on',...
    'PaperUnits', 'inches',...
    'PaperPosition',[0 0 W H],...
    'PaperSize',[W H])

ax=axes
hold on
axis([Rl/R*W Ru/R*W 0 H*(1+n)/n])
set(ax, 'XAxisLocation', 'top')
ax.YTick=(1:n)*H/n;
ax.YTickLabel = Studynames;
ax.XTick=(ceil(Rl/2):1:floor(Ru/2))/R*W*2;
ax.XTickLabel = ceil(Rl/2)*2:2:floor(Ru/2)*2+10^-8;
ax.FontSize=9;
line([0 0],[0 n+1],'Color',GREY)
line([1.96/R*W 1.96/R*W],[0 n+1],'Color',GREY)
line([-1.96/R*W -1.96/R*W],[0 n+1],'Color',GREY)


sc1=scatter(Z1/R*W, (1:n)/n*H, 4, BLUE, 'x') %original
sc2=scatter(Z1_M/R*W, ((1:n)-.35)/n*H, 4,[0 0 0], 'filled') %adjusted


for i=1:n
    line([Z1(i)-1.96 Z1(i)+1.96]/R*W,[i i]/n*H,'Color',BLUE,'Linewidth',1) %original
    line([Z1_L(i) Z1_U(i)]/R*W,([i i]-.3)/n*H,'Color',[0 0 0],'Linewidth',1) %adjusted
    
    line([1 1]*Z1_LB(i)/R*W,([i-.4 i-.2])/n*H,'Color',[0 0 0],'Linewidth',1) %bonferroni lower
    line([1 1]*Z1_UB(i)/R*W,([i-.4 i-.2])/n*H,'Color',[0 0 0],'Linewidth',1) %bonferroni upper
end


legend([sc1 sc2],{'Original Estimates','Adjusted Estimates'},'Location','SE', 'FontSize', 9)


print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'OriginalAndAdjustedBonferroni.pdf'])



%%
%plot corrected estimators and confidence sets
if symmetric==1
    xgrid=0:.01:5;
    alpha=0.05;
    
    Theta_U_store=zeros(length(xgrid),1);
    Theta_L_store=zeros(length(xgrid),1);
    Theta_M_store=zeros(length(xgrid),1);
    for n=1:length(xgrid)
        X=xgrid(n);
        
        g_U=@(lambda)(alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_M=@(lambda) (1/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        
        theta_U=fminsearch(g_U,X);
        theta_L=fminsearch(g_L,X);
        theta_M=fminsearch(g_M,X);
        
        Theta_U_store(n)=theta_U;
        Theta_L_store(n)=theta_L;
        Theta_M_store(n)=theta_M;
        
        %Calculate Bonferroni corrected estimates and confidence bounds
        g_UB=@(lambda)(bonf_alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_LB=@(lambda)(1-bonf_alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        
        theta_UB(n,1)=fminsearch(g_UB,Theta_U_store(n,1));
        theta_LB(n,1)=fminsearch(g_LB,Theta_L_store(n,1));
        
        %Calculate derivatives of corrections with respect to parameters via
        %implicit function theorem
        thetaU_plus=theta_UB(n,1)+stepsize;
        thetaU_minus=theta_UB(n,1)-stepsize;
        F_Uplus=Step_function_normal_cdf(X,thetaU_plus,1,[Psihat_use 1],cutoffs,symmetric);
        F_Uminus=Step_function_normal_cdf(X,thetaU_minus,1,[Psihat_use 1],cutoffs,symmetric);
        dFUdtheta=(F_Uplus-F_Uminus)/(2*stepsize);
        
        thetaL_plus=theta_LB(n,1)+stepsize;
        thetaL_minus=theta_LB(n,1)-stepsize;
        F_Lplus=Step_function_normal_cdf(X,thetaL_plus,1,[Psihat_use 1],cutoffs,symmetric);
        F_Lminus=Step_function_normal_cdf(X,thetaL_minus,1,[Psihat_use 1],cutoffs,symmetric);
        dFLdtheta=(F_Lplus-F_Lminus)/(2*stepsize);
        
        for n1=1:length(Psihat_use)
            Psi_plus=Psihat_use;
            Psi_plus(n1)=Psi_plus(n1)+stepsize;
            Psi_minus=Psihat_use;
            Psi_minus(n1)=Psi_minus(n1)-stepsize;
            
            F_Uplus=Step_function_normal_cdf(X,theta_UB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
            F_Uminus=Step_function_normal_cdf(X,theta_UB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
            dFUdbeta(n1,1)=(F_Uplus-F_Uminus)/(2*stepsize);
            
            F_Lplus=Step_function_normal_cdf(X,theta_LB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
            F_Lminus=Step_function_normal_cdf(X,theta_LB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
            dFLdbeta(n1,1)=(F_Lplus-F_Lminus)/(2*stepsize);
        end
        dthetaUdbeta=-dFUdbeta/dFUdtheta;
        dthetaLdbeta=-dFLdbeta/dFLdtheta;
        
        sigma_thetaU(n,1)=(dthetaUdbeta'*Varhat*dthetaUdbeta)^.5;
        sigma_thetaL(n,1)=(dthetaLdbeta'*Varhat*dthetaLdbeta)^.5;
    end
    Theta_UB_store=theta_UB+norminv(1-bonf_beta)*sigma_thetaU;
    Theta_LB_store=theta_LB-norminv(1-bonf_beta)*sigma_thetaL;
else
    xgrid=-5:.01:5;
    alpha=0.05;
    
    Theta_U_store=zeros(length(xgrid),1);
    Theta_L_store=zeros(length(xgrid),1);
    Theta_M_store=zeros(length(xgrid),1);
    sigma_thetaU=zeros(length(xgrid),1);
    sigma_thetaL=zeros(length(xgrid),1);
    theta_UB=zeros(length(xgrid),1);
    theta_LB=zeros(length(xgrid),1);
    for n=1:length(xgrid)
        X=xgrid(n);
        
        g_U=@(lambda)(alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_M=@(lambda) (1/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        
        theta_U=fminsearch(g_U,X);
        theta_L=fminsearch(g_L,X);
        theta_M=fminsearch(g_M,X);
        
        Theta_U_store(n)=theta_U;
        Theta_L_store(n)=theta_L;
        Theta_M_store(n)=theta_M;
        
        %Calculate Bonferroni corrected estimates and confidence bounds
        g_UB=@(lambda)(bonf_alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        g_LB=@(lambda)(1-bonf_alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use 1],cutoffs,symmetric)).^2;
        
        theta_UB(n,1)=fminsearch(g_UB,Theta_U_store(n,1));
        theta_LB(n,1)=fminsearch(g_LB,Theta_L_store(n,1));
        
        %Calculate derivatives of corrections with respect to parameters via
        %implicit function theorem
        thetaU_plus=theta_UB(n,1)+stepsize;
        thetaU_minus=theta_UB(n,1)-stepsize;
        F_Uplus=Step_function_normal_cdf(X,thetaU_plus,1,[Psihat_use 1],cutoffs,symmetric);
        F_Uminus=Step_function_normal_cdf(X,thetaU_minus,1,[Psihat_use 1],cutoffs,symmetric);
        dFUdtheta=(F_Uplus-F_Uminus)/(2*stepsize);
        
        thetaL_plus=theta_LB(n,1)+stepsize;
        thetaL_minus=theta_LB(n,1)-stepsize;
        F_Lplus=Step_function_normal_cdf(X,thetaL_plus,1,[Psihat_use 1],cutoffs,symmetric);
        F_Lminus=Step_function_normal_cdf(X,thetaL_minus,1,[Psihat_use 1],cutoffs,symmetric);
        dFLdtheta=(F_Lplus-F_Lminus)/(2*stepsize);
        
        for n1=1:length(Psihat_use)
            Psi_plus=Psihat_use;
            Psi_plus(n1)=Psi_plus(n1)+stepsize;
            Psi_minus=Psihat_use;
            Psi_minus(n1)=Psi_minus(n1)-stepsize;
            
            F_Uplus=Step_function_normal_cdf(X,theta_UB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
            F_Uminus=Step_function_normal_cdf(X,theta_UB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
            dFUdbeta(n1,1)=(F_Uplus-F_Uminus)/(2*stepsize);
            
            F_Lplus=Step_function_normal_cdf(X,theta_LB(n,1),1,[Psi_plus 1],cutoffs,symmetric);
            F_Lminus=Step_function_normal_cdf(X,theta_LB(n,1),1,[Psi_minus 1],cutoffs,symmetric);
            dFLdbeta(n1,1)=(F_Lplus-F_Lminus)/(2*stepsize);
        end
        dthetaUdbeta=-dFUdbeta/dFUdtheta;
        dthetaLdbeta=-dFLdbeta/dFLdtheta;
        
        sigma_thetaU(n,1)=(dthetaUdbeta'*Varhat*dthetaUdbeta)^.5;
        sigma_thetaL(n,1)=(dthetaLdbeta'*Varhat*dthetaLdbeta)^.5;
    end
    
    Theta_UB_store=theta_UB+norminv(1-bonf_beta)*sigma_thetaU;
    Theta_LB_store=theta_LB-norminv(1-bonf_beta)*sigma_thetaL;
end

%%
fig=figure('Visible','on',...
    'PaperUnits', 'inches',...
    'PaperPosition',[0 0 4 4],...
    'PaperSize',[4 4])


plot(xgrid',[xgrid'-1.96],'Color',GREY,'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',GREY,'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',GREY,'Linewidth',1.5)

xmin=min(xgrid);
xmax=max(xgrid);

ymin=min(min(Theta_LB_store,xmin-1.96));
ymax=max(max(Theta_UB_store,xmax+1.96));

for n=ceil(xmin)+1:1:floor(xmax)-1
    line([n n],[ymin ymax],'LineStyle',':','Color',GREY,'Linewidth',1.5)
end

for n=ceil(ymin):1:floor(ymax)
    line([xmin xmax],[n n],'LineStyle',':','Color',GREY,'Linewidth',1.5)
end

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
p3=plot(xgrid',[Theta_LB_store], 'Color',[0 0 0],'Linewidth',1)
p4=plot(xgrid',[Theta_UB_store], 'Color',[0 0 0],'Linewidth',1)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p3,p2], {'95% Confidence Bounds','Bonferroni Corrected 95% Bounds','Median Unbiased Estimator'},'Location','northoutside','Fontsize',9)
xlabel('X','Fontsize',9)
ylabel('Estimated \theta','Fontsize',9)
axis square tight

%%
print(fig,'-dpdf', ['/Users/britsharoni/Documents/Harvard/RAing/Isaiah Andrews/Publication Bias/Codes/GMM Estimation Matlab/FiguresandTables/' name 'Correction_plot.pdf'])
