function [moment_mean, moment_var, raw_moments] = MetastudyMoments(betap, cutoffs, symmetric, X, sigma)
%Calculate GMM moments for metastudy applications

n=length(X);
betap=betap';

%regressors for step function p
T=X./sigma;

Tpowers=zeros(n,length(cutoffs)+1);
if symmetric==1
    Tpowers(:,1)=abs(T)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(abs(T)<cutoffs(m)).*(abs(T)>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=abs(T)>=cutoffs(end);
else
    Tpowers(:,1)=T<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(T<cutoffs(m)).*(T>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=T>=cutoffs(end);
end

phat=Tpowers*betap;

%%%create moments
Xmat1=repmat(X,1,length(X));
Xmat2=Xmat1';
sigmamat1=repmat(sigma,1,length(X));
sigmamat2=sigmamat1';
indicator=(sigmamat1>=sigmamat2);
sigmadiff=(indicator.*(sigmamat1.^2-sigmamat2.^2)).^.5+...
((1-indicator).*(sigmamat2.^2-sigmamat1.^2)).^.5;
sigmadiff=real(sigmadiff);
pmat1=repmat(phat,1,length(X));
pmat2=pmat1';

moment_mean=zeros(1,length(cutoffs));
rhat=zeros(n,length(cutoffs));
if symmetric==1
    for k=1:length(cutoffs)
        c=cutoffs(k);
            base_moments=(pmat2.^-1).*(pmat1.^-1).*indicator...
            .*((normcdf((c.*sigmamat1-Xmat2)./sigmadiff)-...
            normcdf((-c.*sigmamat1-Xmat2)./sigmadiff))...
            -((Xmat1<=c.*sigmamat1)-(Xmat1<=-c.*sigmamat1)))...
            +(pmat1.^-1).*(pmat2.^-1).*(1-indicator)...
            .*((normcdf((c.*sigmamat2-Xmat1)./sigmadiff)-...
            normcdf((-c.*sigmamat2-Xmat1)./sigmadiff))...
            -((Xmat2<=c.*sigmamat2)-(Xmat2<=-c.*sigmamat2)));      
 
        base_moments=base_moments-diag(diag(base_moments));
        base_moments(isnan(base_moments))=0;
        moment_mean(1,k)=nchoosek(n,2)^(-1)/2*sum(sum(base_moments));
        %Build normalization for variance into rhat to ensure get correct
        %answers with clustered variance estimator
        rhat(:,k)=2*(n-1)^-1*sum(base_moments,2);
    end
else
    for k=1:length(cutoffs)
        c=cutoffs(k);
        base_moments=(pmat2.^-1).*(pmat1.^-1).*indicator...
            .*(normcdf((c.*sigmamat1-Xmat2)./sigmadiff)...
            -(Xmat1<=c.*sigmamat1))+...
            (pmat2.^-1).*(pmat1.^-1).*(1-indicator)...
            .*(normcdf((c.*sigmamat2-Xmat1)./sigmadiff)...
            -(Xmat2<=c.*sigmamat2));
               
        base_moments=base_moments-diag(diag(base_moments));
        base_moments(isnan(base_moments))=0;
        moment_mean(1,k)=nchoosek(n,2)^(-1)/2*sum(sum(base_moments));
        %Build normalization for variance into rhat to ensure get correct
        %answers with clustered variance estimator
        rhat(:,k)=2*(n-1)^-1*sum(base_moments,2);
    end
end
moment_var=cov(rhat);
raw_moments=rhat;
end

